pub fn release_execution_permit()Expand description
Releases (drops) the current thread’s execution permit if one is installed. Idempotent, and a no-op when no permit is installed. Called by blocking primitives immediately before they park or spin.
pub fn release_execution_permit()Releases (drops) the current thread’s execution permit if one is installed. Idempotent, and a no-op when no permit is installed. Called by blocking primitives immediately before they park or spin.